Extra models
=====================================

The extra models are predefined models that you can use for classification without change almost anything.


In the module ml.clf.extended.w_gpy you can use the models:

* GPC (Gaussian Process Classification)
* SVGPC (Stochastic Variational Gaussian Process Classification)

In the module ml.clf.extended.w_sklearn are:

* SVC (Support Vector Component)
* RandomForest
* ExtraTrees
* LogisticRegression
* SGDClassifier
* AdaBoost
* GradientBoost

In the module ml.clf.extended.w_tflearn are:

* MLP (MultiLayer Perceptron)

In the module ml.clf.extended.w_keras are:

* FCNet (Full Conected Network)
